clear all; clc;

data             = csvread('inflation.csv');
yfull            = data(:,3);
lag              = 4;
dateindex        = data(lag+1:end,1:2);

y                = yfull(lag+1:end,1);
bigt             = size(y,1);
z                = ones(bigt,1);
for j=1:lag
   z             = [z yfull(lag+1-j:end-j,1)]; 
end
q                = size(z,2);
x                = [];
p                = 0;
N                = 3;
M                = 3;
trm              = 0.1;
h                = round(trm*bigt);

%  -------------------------------------------
vrobust          = 1;
robust           = 0;
prewhit          = 0;
typekbv          = 2;
typekbc          = 2;
siglev           = [10;5;2.5;1];

% --------------------------------------------
disp('The options chosen are')
disp(['trimming = ' num2str(trm)])
disp(['vrobust = ' num2str(vrobust)])
disp(['robust = ' num2str(robust)])
disp(['The maximum number of variance breaks is: ' num2str(N)])
disp(['The maximum number of coefficient breaks is: ' num2str(M)])

disp('************************************************************')
disp('a-1) supLR4 tests against fixed numbers of variance and coefficient breaks.')
disp('----------------------------------------------------')
slr4             = zeros(M,N);
for m=1:M
   for n=1:N
     slr4(m,n) = pslr4(y,z,q,m,n,x,p,bigt,robust,vrobust,prewhit,h,typekbv,typekbc);    
     disp(['The supLR4 test for no breaks versus ' num2str(n) ' variance breaks and ' num2str(m)... 
           ' coefficient breaks is :' num2str(slr4(m,n))])
       for j=1:4
        cv4 = getcv4(j,trm,q);
        disp(['  The critical values at the ' num2str(siglev(j,1)) '% level is ' num2str(cv4(m,n))])
       end
   end
end

disp('----------------------------------------------------')
disp('a-2) UDmax4 tests against unknown number of coefficient and variance breaks.')
disp('----------------------------------------------------')
disp(['The UDmax4 test is: ' num2str(max(max(slr4)))])
for j=1:4
   cvdmax4 = getdmax4(j,trm,M,N);
   disp(['  The critical values at the ' num2str(siglev(j,1)) '% level is ' num2str(cvdmax4(q,1))])
end

disp('************************************************************')
disp('b-1) supLR3 and supLR tests against fixed numbers of coefficient breaks.')
disp('----------------------------------------------------')
slr0             = zeros(M,1);
slr3             = zeros(M,N);
for n=0:N
   for m=1:M
       if n==0
          slr0(m,1) = pslr0(y,z,q,m,x,p,bigt,robust,prewhit,h,typekbc);
          disp(['The supLR test for no coefficient breaks versus ' num2str(m) ' coefficient breaks given no variance breaks is :' num2str(slr0(m,1))])          
          for j=1:4
           cv1 = getcv1(j,trm);
           disp(['  The critical values at the ' num2str(siglev(j,1)) '% level is ' num2str(cv1(q,m))])
          end
       else
          slr3(m,n) = pslr3(y,z,q,m,n,x,p,bigt,robust,prewhit,h,typekbc);
          disp(['The supLR3 test for no coefficient breaks versus ' num2str(m) ' coefficient breaks given ' num2str(n)... 
           ' variance breaks is :' num2str(slr3(m,n))])
          for j=1:4
           cv1 = getcv1(j,trm);
           disp(['  The critical values at the ' num2str(siglev(j,1)) '% level is ' num2str(cv1(q,m))])
          end      
       end
   end
end
disp('----------------------------------------------------')
disp('b-2) UDmax3 and UDmax tests against unknown number of coefficient breaks.')
disp('----------------------------------------------------')
disp(['The UDmax test given no variance breaks is: ' num2str(max(slr0(:,1)))])
for j=1:4
  cvm = getdmax(j,trm);
  disp(['  The critical value at the ' num2str(siglev(j,1)) '% level is ' num2str(cvm(q,1))])
end
for n=1:N
disp(['The UDmax3 test given ' num2str(n) ' variance breaks is: ' num2str(max(slr3(:,n)))])
   for j=1:4
     cvm = getdmax(j,trm);
     disp(['  The critical value at the ' num2str(siglev(j,1)) '% level is ' num2str(cvm(q,1))])
   end      
end

disp('----------------------------------------------------')
disp('b-3) supLR9 sequential tests to determine the number of coefficient breaks.')
disp('----------------------------------------------------')
slr9                  = zeros(M+1,N+1);
slr9(1,1)             = slr0(1,1);
slr9(1,2:end)         = slr3(1,:);
for n=0:N
for m=1:M
    slr9(m+1,n+1)     = pslr9(y,z,q,m,n,x,p,bigt,vrobust,prewhit,h,typekbc);
    if m>0
    disp(['The supLR9(' num2str(m+1) '|' num2str(m) ') test given ' num2str(n)...
        ' variance breaks is :' num2str(slr9(m+1,n+1))])
    for j=1:4
     cv2 = getcv2(j,trm);
     disp(['  The critical value at the ' num2str(siglev(j,1)) '% level is ' num2str(cv2(q,m+1))])
    end
    end
end
cv2 = getcv2(1,trm);
for m=0:M
    if slr9(m+1,n+1)<=cv2(q,m+1)
       mh           = m;
       break
    end
end
    disp(['The sequential procedure estimated the number of coefficient breaks given ' num2str(n)...
          ' variance breaks at: ' num2str(mh)])
    if mh>=1
        [Tc,Tv]   = jdateestim(y,z,q,mh,n,x,p,bigt,h);
        for j=1:mh
        disp(['The estimated coefficient break date is ' num2str(dateindex(Tc(j,1),1)) 'Q' num2str(dateindex(Tc(j,1),2))])
        end
    end
end

disp('************************************************************')
disp('c-1) supLR2 and supLR1 tests against fixed numbers of variance breaks.')
disp('----------------------------------------------------')
slr1             = zeros(N,1);
slr2             = zeros(M,N);
for m=0:M
   for n=1:N
       if m==0
          slr1(n,1) = pslr1(y,z,q,n,x,p,bigt,vrobust,prewhit,h,typekbv);
          disp(['The supLR1 test for no breaks versus ' num2str(n) ' variance breaks given no coefficient breaks is :' num2str(slr1(n,1))])          
          for j=1:4
           cv1 = getcv1(j,trm);
           disp(['  The critical values at the ' num2str(siglev(j,1)) '% level is ' num2str(cv1(1,n))])
          end
       else
          slr2(m,n) = pslr2(y,z,q,m,n,x,p,bigt,vrobust,prewhit,h,typekbv);
          disp(['The supLR2 test for no breaks versus ' num2str(n) ' variance breaks given ' num2str(m)... 
           ' coefficient breaks is :' num2str(slr2(m,n))])
          for j=1:4
           cv1 = getcv1(j,trm);
           disp(['  The critical values at the ' num2str(siglev(j,1)) '% level is ' num2str(cv1(1,n))])
          end      
       end
   end
end
disp('----------------------------------------------------')
disp('c-2) UDmax2 and UDmax1 tests against unknown number of variance breaks.')
disp('----------------------------------------------------')
disp(['The UDmax1 test given no coefficient breaks is: ' num2str(max(max(slr1(:,1))))])
for j=1:4
  cvm = getdmax(j,trm);
  disp(['  The critical value at the ' num2str(siglev(j,1)) '% level is ' num2str(cvm(1,1))])
end
for m=1:M
disp(['The UDmax2 test given ' num2str(m) ' coefficient breaks is: ' num2str(max(max(slr2(m,:))))])
   for j=1:4
     cvm = getdmax(j,trm);
     disp(['  The critical value at the ' num2str(siglev(j,1)) '% level is ' num2str(cvm(1,1))])
   end      
end
disp('----------------------------------------------------')
disp('c-3) supLR10 sequential tests to determine the number of variance breaks.')
disp('----------------------------------------------------')
slr10                 = zeros(M+1,N+1);
slr10(1,1)            = slr1(1,1);
slr10(2:end,1)        = slr2(:,1);
for m=0:M
  for n=1:N
    slr10(m+1,n+1)    = pslr10(y,z,q,m,n,x,p,bigt,vrobust,prewhit,h,typekbv);
    if n>0
    disp(['The supLR10(' num2str(n+1) '|' num2str(n) ') test given ' num2str(m)...
          ' coefficient breaks is :' num2str(slr10(m+1,n+1))])
    for j=1:4
     cv2 = getcv2(j,trm);
     disp(['  The critical value at the ' num2str(siglev(j,1)) '% level is ' num2str(cv2(1,n+1))])
    end
    end
  end
  cv2 = getcv2(1,trm);
  nh  = 0;
  for n=0:N
    if slr10(m+1,n+1)<=cv2(1,n+1)
       nh         = n;
       break
    end
  end
  disp(['The sequential procedure estimated the number of variance breaks given ' num2str(m)...
        ' coefficient breaks at: ' num2str(nh)])
  if nh>=1
      [Tc,Tv]   = jdateestim(y,z,q,m,nh,x,p,bigt,h);
      for j=1:nh
      disp(['The estimated variance break date is ' num2str(dateindex(Tv(j,1),1)) 'Q' num2str(dateindex(Tv(j,1),2))])
      end
  end
end
disp('************************************************************')

